### Name: glymet
### Title: Glyphosate and metsulfuron-methyl tested on algae.
### Aliases: glymet
### Keywords: datasets

### ** Examples


## Fitting the model with freely varying ED50 values
glymet.mfree <- drm(rgr~dose, pct, data = glymet, 
fct = LL.3(), pmodels = list(~factor(pct),~1,~factor(pct) - 1),
adjust = "bc1") 

## Lack-of-fit test
anova(glymet.mfree)  # not really acceptable
summary(glymet.mfree)

## Plotting isobole structure
isobole(glymet.mfree, exchange=0.01)

## Fitting the concentration addition model
glymet.mca <- mixture(rgr~dose, pct, data = glymet, collapse = ~factor(pct), 
fct = LL.3(), model = "CA", boxcox = TRUE)

## Comparing to model with freely varying e parameter
anova(glymet.mca, glymet.mfree)  # borderline accepted

## Plotting isobole based on concentration addition
isobole(glymet.mfree, glymet.mca, exchange=0.01)  # acceptable fit

## Fitting the Hewlett model
glymet.mhew <- mixture(rgr~dose, pct, data = glymet, collapse = ~factor(pct), 
fct = LL.3(), model = "Hewlett", boxcox = TRUE)

## Comparing to model with freely varying e parameter
anova(glymet.mca, glymet.mhew)  
# borderline accepted
# the Hewlett model offers no improvement over concentration addition

## Plotting isobole based on concentration addition
isobole(glymet.mfree, glymet.mhew, exchange=0.01)  
# no improvement over concentration addition




